bl_info = {
    "name": "Hyperfy Tools",
    "author": "Howie Duhzit",
    "version": (1, 1, 0),
    "blender": (4, 3, 0),
    "location": "View3D > Sidebar > Hyperfy",
    "description": "Tools for creating Hyperfy assets with physics and colliders",
    "category": "3D View",
}

import bpy
from . import HyperfyTools
from bpy.types import Panel, Operator

def register():
    # Register properties
    bpy.types.Scene.hyperfy_physics_type = bpy.props.EnumProperty(
        name="Type",
        description="Physics type for the rigidbody",
        items=[
            ('static', "Static", "Non-moving collision object"),
            ('dynamic', "Dynamic", "Physics-driven object"),
            ('kinematic', "Kinematic", "Animated collision object")
        ],
        default='static'
    )
    bpy.types.Scene.hyperfy_mass = bpy.props.FloatProperty(
        name="Mass",
        description="Mass of the rigidbody",
        default=1.0,
        min=0.0,
        max=1000.0
    )
    
    # Mesh properties
    bpy.types.Scene.hyperfy_cast_shadow = bpy.props.BoolProperty(
        name="Cast Shadow",
        description="Whether the mesh should cast shadows",
        default=True
    )
    bpy.types.Scene.hyperfy_receive_shadow = bpy.props.BoolProperty(
        name="Receive Shadow",
        description="Whether the mesh should receive shadows",
        default=True
    )
    
    # Collider properties
    bpy.types.Scene.hyperfy_collider_type = bpy.props.EnumProperty(
        name="Collider Type",
        description="Type of collision shape",
        items=[
            ('box', "Box", "Box collision shape"),
            ('sphere', "Sphere", "Sphere collision shape"),
            ('geometry', "Geometry", "Use exact mesh geometry for collision (complex)"),
            ('simple', "Simple Collision", "Generate simplified collision from mesh")
        ],
        default='box'
    )
    bpy.types.Scene.hyperfy_convex = bpy.props.BoolProperty(
        name="Convex",
        description="Use convex collision shape (more performant, allows dynamic-dynamic collisions)",
        default=True
    )
    bpy.types.Scene.hyperfy_trigger = bpy.props.BoolProperty(
        name="Trigger",
        description="Make this a trigger volume (no physical collisions)",
        default=False
    )
    
    # Box collider size properties
    bpy.types.Scene.hyperfy_box_width = bpy.props.FloatProperty(
        name="Width",
        description="Width of box collider",
        default=1.0,
        min=0.01
    )
    bpy.types.Scene.hyperfy_box_height = bpy.props.FloatProperty(
        name="Height", 
        description="Height of box collider",
        default=1.0,
        min=0.01
    )
    bpy.types.Scene.hyperfy_box_depth = bpy.props.FloatProperty(
        name="Depth",
        description="Depth of box collider",
        default=1.0,
        min=0.01
    )
    
    # Sphere collider properties
    bpy.types.Scene.hyperfy_sphere_radius = bpy.props.FloatProperty(
        name="Radius",
        description="Radius of sphere collider",
        default=0.5,
        min=0.01
    )

    # Register classes
    for cls in HyperfyTools.classes:
        bpy.utils.register_class(cls)

def unregister():
    # Unregister classes
    for cls in reversed(HyperfyTools.classes):
        bpy.utils.unregister_class(cls)
    
    # Remove properties
    del bpy.types.Scene.hyperfy_physics_type
    del bpy.types.Scene.hyperfy_mass
    del bpy.types.Scene.hyperfy_cast_shadow
    del bpy.types.Scene.hyperfy_receive_shadow
    del bpy.types.Scene.hyperfy_collider_type
    del bpy.types.Scene.hyperfy_convex
    del bpy.types.Scene.hyperfy_trigger
    del bpy.types.Scene.hyperfy_box_width
    del bpy.types.Scene.hyperfy_box_height
    del bpy.types.Scene.hyperfy_box_depth
    del bpy.types.Scene.hyperfy_sphere_radius

if __name__ == "__main__":
    register()
